==> realtime_trains_py-2025.3.0b3.tar.gz: realtime_trains_py-2025.3.0b3/SECURITY.md <==
# Security Policy: realtime-trains-lang 

## Supported Versions

We release updates and patches regularly. Below are the versions of this project that are actively supported and maintained. If a version isn't shown in this table, then it is no longer supported. Specific versions that will no longer be supported in the next few months will be shown too.

| Version (realtime-trains-py)  | Supported          |
|-------------------------------|--------------------|
| 2025.2.x                      | :white_check_mark: |
| 2025.2.xbx                    | :white_check_mark: |

If you are using an unsupported version, please upgrade to a supported version to receive the latest security updates.

## Reporting a Vulnerability

We take the security of the realtime-trains-lang packages seriously. If you discover a security vulnerability, please report it as soon as possible by emailing us at **[anonymous4401.ad@gmail.com](mailto:anonymous4401.ad@gmail.com)**.

Ensure you include the details of the issue. Include the following information in your report:
   - A detailed description of the vulnerability.
   - Steps to reproduce the issue.
      - How did you come across the vulnerability?
   - The potential impact or risk.

**Do not disclose the vulnerability publicly.** Sharing potential vulnerabilities could lead to exploitation or other adverse consequences.

We aim to acknowledge your report within **3 working days** and will provide a more detailed response within **10 working days**. 

After confirming the issue, we will:
- Collaborate with you to validate and address the vulnerability.
- Credit you for your discovery if desired and appropriate.

## Security Updates

We will post updates about resolved security vulnerabilities in the **[releases section of this repository.](https://github.com/realtime-trains-lang/realtime-trains-py/releases)**.

## Scope

This security policy applies to vulnerabilities in the source code and dependencies of this repository. It does not cover:
- General bugs that do not pose a security risk.
- Issues related to third-party services or tools.

Thank you for helping us keep realtime-trains-lang secure!

==> realtime_trains_py-2025.3.2.tar.gz: realtime_trains_py-2025.3.2/SECURITY.md <==
# Security Policy: realtime-trains-lang 

## Supported Versions

We release updates and patches regularly. Below are the versions of this project that are actively supported and maintained. If a version isn't shown in this table, then it is no longer supported. Specific versions that will no longer be supported in the next few months will be shown too.

| Version (realtime-trains-py)  | Supported          |
|-------------------------------|--------------------|
| 2025.3.x                      | :white_check_mark: |
| 2025.3.xbx                    | :white_check_mark: |
| 2025.2.x                      | :warning: Ending 01/06/25 |
| 2025.2.xbx                    | :warning: Ending 15/05/25 |

If you are using an unsupported version, please upgrade to a supported version to receive the latest security updates.

## Reporting a Vulnerability

We take the security of the realtime-trains-lang packages seriously. If you discover a security vulnerability, please report it as soon as possible by emailing us at **[anonymous4401.ad@gmail.com](mailto:anonymous4401.ad@gmail.com)**.

Ensure you include the details of the issue. Include the following information in your report:
   - A detailed description of the vulnerability.
   - Steps to reproduce the issue.
      - How did you come across the vulnerability?
   - The potential impact or risk.

**Do not disclose the vulnerability publicly.** Sharing potential vulnerabilities could lead to exploitation or other adverse consequences.

We aim to acknowledge your report within **3 working days** and will provide a more detailed response within **10 working days**. 

After confirming the issue, we will:
- Collaborate with you to validate and address the vulnerability.
- Credit you for your discovery if desired and appropriate.

## Security Updates

We will post updates about resolved security vulnerabilities in the **[releases section of this repository.](https://github.com/realtime-trains-lang/realtime-trains-py/releases)**.

## Scope

This security policy applies to vulnerabilities in the source code and dependencies of this repository. It does not cover:
- General bugs that do not pose a security risk.
- Issues related to third-party services or tools.

Thank you for helping us keep realtime-trains-lang secure!
